@@ -6,6 +6,7 @@ import re
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import models
 from django.db.backends.postgresql_psycopg2.version import get_version
+from django import forms
 from django.utils import six
 
 
@@ -16,6 +17,7 @@ class JSONField(six.with_metaclass(models.SubfieldBase, models.Field)):
     def __init__(self, null=True, blank=True, default={}, *args, **kwargs):
         super(JSONField, self).__init__(*args, null=null, blank=blank,
                                         default=default, **kwargs)
+
     def db_type(self, connection):
         return 'json' if connection.vendor == 'postgresql' and get_version(connection) >= 90200 else 'text'
 
@@ -44,6 +46,11 @@ class JSONField(six.with_metaclass(models.SubfieldBase, models.Field)):
         value = self._get_val_from_obj(obj)
         return self.get_prep_value(value)
 
+    def formfield(self, **kwargs):
+        defaults = {'form_class': JSONFormField}
+        defaults.update(kwargs)
+        return super(JSONField, self).formfield(**defaults)
+
 try:
     from south.modelsinspector import add_introspection_rules
     add_introspection_rules([(
@@ -59,31 +66,10 @@ except ImportError:
     pass
 
 
+class JSONFormField(forms.CharField):
+    widget = forms.Textarea
 
-# class JSONFormField(forms.Field):
-#     default_error_messages = {
-#         'invalid': _('Enter a valid json'),
-#     }
-#
-#     def __init__(self, max_length=None, min_length=None, *args, **kwargs):
-#         super(JSONFormField, self).__init__(*args, **kwargs)
-#
-#     def clean(self, value):
-#         if not value:
-#             return
-#         # If Django already parsed value to list
-#         if isinstance(value, list):
-#             return value
-#         try:
-#             return value.split(self.delim)
-#         except Exception:
-#             raise ValidationError(self.error_messages['invalid'])
-#
-#     def prepare_value(self, value):
-#         if value:
-#             return self.delim.join(str(v) for v in value)
-#         else:
-#             return super(JSONFormField, self).prepare_value(value)
-#
-#     def to_python(self, value):
-#         return value.split(self.delim)
+    def prepare_value(self, value):
+        if isinstance(value, six.string_types):
+            return value
+        return json.dumps(value, cls=DjangoJSONEncoder)
